@@ -7,10 +7,8 @@ Version   : 2012.09
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
-This script gives some usefull functions in relation with the powerfull LaTeX
+This script gives some useful functions in relation with the powerful LaTeX
 langage for typing scientific documents.
-
-See the documentation for more details.
 """
 
 import os
@@ -25,6 +23,13 @@ from mistool import os_use
 # ------------------------- #
 
 class LaTeXUseError(ValueError):
+    """
+-----------------
+Small description
+-----------------
+
+Base class for errors in the ``latex_use`` module of the package ``mistool``.
+    """
     pass
 
 def __raiseSomeError(
@@ -32,6 +37,13 @@ def __raiseSomeError(
     path,
     action
 ):
+    """
+-----------------
+Small description
+-----------------
+
+This method simply eases the raising of some specific errors.
+    """
     if action == 'access':
         action = 'needs the "Super User\'s rights"'
 
@@ -85,6 +97,10 @@ def escape(
     mode = "text"
 ):
     """
+-----------------
+Small description
+-----------------
+
 In LaTeX language, somme character has one meaning. The purpose of this function
 is to escape all this special charcaters so as to see them in the output
 produced by LaTeX.
@@ -95,7 +111,12 @@ For example, ``escape("\OH/ & ...")`` is equal to ``"\textbackslash{}OH/ \&
 ``mode = "math"``. In math formulas and in simple text, the backslash is
 indicated by using two different LaTeX commands.
 
-The function ``escape`` has two variables.
+
+-------------
+The arguments
+-------------
+
+This function uses the following variables.
 
     1) ``text`` is simply the text to change.
 
@@ -104,9 +125,11 @@ The function ``escape`` has two variables.
     produced by LaTeX. You can also use ``mode = "math"`` to indicate something
     that appears in one formula.
 
-Two global dictionaries are used : ``CHAR_TO_ESCAPE`` indicates only characters
-that must be escaped whit one backslash ``\``, and ``CHAR_TO_LATEXIFY`` is for
-expressions that needs one LaTeX command.
+
+info::
+    Two global dictionaries are used : ``CHAR_TO_ESCAPE`` indicates only
+    characters that must be escaped whit one backslash ``\``, and
+    ``CHAR_TO_LATEXIFY`` is for expressions that needs one LaTeX command.
     """
     if not mode in CHAR_TO_ESCAPE:
         raise LaTeXUseError(
@@ -152,18 +175,27 @@ expressions that needs one LaTeX command.
 
 class Build(object):
     """
+-----------------
+Small description
+-----------------
+
 This class defines methods related to the compilation of LaTeX documents.
 
-The variables used are the following ones.
+-------------
+The arguments
+-------------
+
+This class uses the following variables.
 
     1) ``path`` is the path of the LaTeX file to compile.
 
-    2) ``repeat`` indicates ow many times the compilation must be done : if the
-    document has one table of content, several compilations are needed. By
+    2) ``repeat`` indicates how many compilations must be done (for example, if
+    the document has one table of content, several compilations are needed). By
     default, ``repeat = 1``.
 
-    3) ``verbose``, which default value is ``True``, is to see or not the
-    informations sent by LaTeX when it compiles.
+    3) ``verbose`` is a boolean with default value ``True``. Use ``verbose`` if
+    you want to see, or not to see, the informations sent by LaTeX when it
+    does the compilation.
     """
 # Source :
 #    * http://docs.python.org/py3k/library/subprocess.html
@@ -216,6 +248,10 @@ The variables used are the following ones.
         repeat
     ):
         """
+-----------------
+Small description
+-----------------
+
 This method launches the compilation in verbose mode or not.
         """
         for i in range(1, repeat + 1):
@@ -241,7 +277,11 @@ This method launches the compilation in verbose mode or not.
         repeat = None
     ):
         """
-This method asks LaTeX to build PDF output.
+-----------------
+Small description
+-----------------
+
+This method calls LaTeX so as to build the PDF output.
         """
         if repeat == None:
             repeat = self.repeat
@@ -343,31 +383,41 @@ def clean(
     verbose = False
 ):
     """
-The aim of this method is to remove extra files build during LaTeX compilations.
+-----------------
+Small description
+-----------------
 
-Here are the arguments available.
+This function removes extra files build during a LaTeX compilation.
+
+
+-------------
+The arguments
+-------------
+
+This function uses the following variables.
 
     1) ``main`` will be either one instance of the class ``Build`` or the path
-    of one file or one directory.
+    of one file or of one directory.
 
-    In the case of one instance of the class ``Build`` or the path of one file,
-    only the file having the same name of the file build, or indicated, will be
+    In the case of one instance of the class ``Build`` or of one file, only the
+    file having the same name of the file build, or indicated, will be
     removed.
 
     If ``main`` is the path of one directory, then the function will look for
-    all files with path::``tex`` extension, an then the eventual extra files
+    all files with path::``tex`` extension, and then the eventual extra files
     associated will be removed. In that case, you can use the two arguments
     ``depth`` and ``verbose``.
 
-    2) ``keep`` is for indicate the list of extensions to keep. This is very
+    2) ``keep`` is for indicate the list of extensions to keep. This can be very
     usefull if you use the default value of the argument ``discard``.
 
     3) ``discard`` is for indicate the list of extensions to discard. By
     default, the extensions to clean are defined in the constant
     ``ALL_EXT_TO_CLEAN``.
 
-    Remark : to build your own list of extensions you can use the dictionary
-    ``CLASSIFIED_TEMP_EXT``.
+    info::
+        If you want to build your own list of extensions you can use the
+        dictionary ``CLASSIFIED_TEMP_EXT``.
 
     4) ``depth`` is the maximal depth for the research of the path::``tex``
     files when ``main`` is the path of one directory. The very special value
@@ -380,7 +430,7 @@ Here are the arguments available.
     argument is usefull only if ``main`` is the path of one directory.
     """
 # One instance of ``Build()``
-    if type(main) == Build:
+    if isinstance(main, Build):
         thePathsNoExt = [main.pathNoExt]
 
 # One file
@@ -432,12 +482,33 @@ Here are the arguments available.
 #    * http://tex.stackexchange.com/questions/69483/create-a-local-texmf-tree-in-miktex
 #    * https://groups.google.com/forum/?hl=fr&fromgroups=#!topic/fr.comp.text.tex/ivuCnUlW7i8
 
-def __mikeTexLocalDirectory():
+def mikeTexLocalDirectory():
+    """
+-----------------
+Small description
+-----------------
+
+You can redefine this function to choose another path than
+path::``C:/texmf-local`` for the directory where we'll put special LaTeX
+packages.
+
+
+warning::
+    Customize this function if you know what you are doing !
+    """
     return 'C:/texmf-local'
 
 def __localDirOfTexLive(
     osName = None
 ):
+    """
+-----------------
+Small description
+-----------------
+
+This function returns the path of the TeX Live directory where we'll put special
+LaTeX packages.
+    """
     if osName == None:
         osName = os_use.system()
 
@@ -463,6 +534,10 @@ def __localDirOfTexLive(
 
 def about():
     """
+-----------------
+Small description
+-----------------
+
 The aim of this function is to give critical informations so to use the function
 ``install`.
 
@@ -493,8 +568,8 @@ The key ``'localDir'`` contains the path to use to install special packages.
             latexFound = True
             latexName = 'miktex'
 
-            if os_use.isDir(__mikeTexLocalDirectory()):
-                localDir = __mikeTexLocalDirectory()
+            if os_use.isDir(mikeTexLocalDirectory()):
+                localDir = mikeTexLocalDirectory()
 
 # Is TeX Live installed ?
         elif '\\texlive\\' in winPath:
@@ -531,6 +606,10 @@ The key ``'localDir'`` contains the path to use to install special packages.
 
 def __issu(localLatexDir):
     """
+-----------------
+Small description
+-----------------
+
 This function tests if the script has been launched by the "Super User".
     """
     path = os.path.join(
@@ -551,10 +630,14 @@ This function tests if the script has been launched by the "Super User".
 
 def makeMiktexLocalDir():
     """
+-----------------
+Small description
+-----------------
+
 This function creates one local directory and add it to the list of directories
 analysed by MiKTeX when it looks for packages.
 
-The path of the local directory is given by ``__mikeTexLocalDirectory()``
+The path of the local directory is given by ``mikeTexLocalDirectory()``
 because this variable is also used by the function ``about`` and ``install``.
 
 Even it is a really bad idea, you can change this path just after the
@@ -570,12 +653,12 @@ importation of the module ``latexUse``.
 
 # Creation of the directory
     try:
-        os_use.makeDir(__mikeTexLocalDirectory())
+        os_use.makeDir(mikeTexLocalDirectory())
 
     except:
         __raiseSomeError(
             kind   = "directory",
-            path   = __mikeTexLocalDirectory(),
+            path   = mikeTexLocalDirectory(),
             action = "create"
         )
 
@@ -584,8 +667,8 @@ importation of the module ``latexUse``.
         args = [
             'initexmf',
             '--admin',
-            '--user-roots=' + __mikeTexLocalDirectory(),
-#           '--register-root=' + __mikeTexLocalDirectory(),
+            '--user-roots=' + mikeTexLocalDirectory(),
+#           '--register-root=' + mikeTexLocalDirectory(),
             '--verbose'
         ]
     )
@@ -601,7 +684,7 @@ importation of the module ``latexUse``.
     print(
         '',
         'The following local directory for MiKTeX has been created.',
-        '\t"{0}"'.format(__mikeTexLocalDirectory()),
+        '\t"{0}"'.format(mikeTexLocalDirectory()),
         sep = "\n"
     )
 
@@ -609,6 +692,10 @@ def refresh(
     aboutLatex = None
 ):
     """
+-----------------
+Small description
+-----------------
+
 This function refreshes the list of packages directly known by the LaTeX
 distribution. This always works in verbose mode (LaTeX is not very talkative
 when it refreshes).
@@ -640,12 +727,23 @@ def install(
     clean = False
 ):
     """
+-----------------
+Small description
+-----------------
+
 This function helps you to easily install unofficial packages to your LaTeX
 distribution.
 
-This function can only be called by one script launched by the super user.
 
-The variables used are the following ones.
+warning::
+    This function can only be called by one script launched by the super user.
+
+
+-------------
+The arguments
+-------------
+
+This function uses the following variables.
 
     1) ``name`` is the name of the LaTeX package to build.
 
