@@ -9,8 +9,6 @@ Mail      : projetmbc@gmail.com
 
 This module contains functions to manipulate easily files, directories and also
 to have informations about the system.
-
-See the documentation for more details.
 """
 
 import os
@@ -24,6 +22,13 @@ import subprocess
 # ------------------------- #
 
 class OsUseError(ValueError):
+    """
+-----------------
+Small description
+-----------------
+
+Base class for errors in the ``os_use`` module of the package ``mistool``.
+    """
     pass
 
 
@@ -33,13 +38,21 @@ class OsUseError(ValueError):
 
 def isFile(path):
     """
-This function simply tests if the path points to one existing file.
+-----------------
+Small description
+-----------------
+
+This function simply tests if the path ``path`` points to an existing file.
     """
     return os.path.isfile(path)
 
 def isDir(path):
     """
-This function simply tests if the path points to one existing directory.
+-----------------
+Small description
+-----------------
+
+This function simply tests if the path ``path`` points to an existing directory.
     """
     return os.path.isdir(path)
 
@@ -48,8 +61,12 @@ def hasExtIn(
     listOfExt
 ):
     """
-This function tests if one path finishs by one of the extensions given in the
-list of extensions.
+-----------------
+Small description
+-----------------
+
+This function tests if the path ``path`` finishes by one of the extensions given
+in the list of extensions ``listOfExt``.
     """
     if '.' in path:
         for oneExtension in listOfExt:
@@ -67,8 +84,12 @@ SEP = os.sep
 
 def name(path):
     """
-This function extracts from one path the name of one file with its extension or
-simply the name of one directory.
+-----------------
+Small description
+-----------------
+
+This function extracts from the path ``path`` the name of the file with its
+extension or simply the name of one directory.
     """
     i = path.rfind(SEP)
 
@@ -76,20 +97,32 @@ simply the name of one directory.
 
 def fileName(path):
     """
-This function extracts the name without its extension of one file given by its
-path.
+-----------------
+Small description
+-----------------
+
+This function extracts from the path ``path`` the name of the file without its
+extension.
     """
     return os.path.splitext(name(path))[0]
 
 def ext(path):
     """
-This function extracts the extension of one file given by its path.
+-----------------
+Small description
+-----------------
+
+This function extracts from the path ``path`` the extension of the file.
     """
     return os.path.splitext(path)[1][1:]
 
 def pathNoExt(path):
     """
-This function removes the extension of one file in its path.
+-----------------
+Small description
+-----------------
+
+This function removes from the path ``path`` the extension of the file.
     """
     i = len(ext(path))
 
@@ -102,8 +135,12 @@ This function removes the extension of one file in its path.
 
 def parentDir(path):
     """
+-----------------
+Small description
+-----------------
+
 This function returns the path of the directory that contains the file or the
-directory corresponding to path.
+directory corresponding to the path ``path``.
     """
     return os.path.dirname(path)
 
@@ -112,34 +149,36 @@ def relativePath(
     sub,
 ):
     """
+-----------------
+Small description
+-----------------
+
 Suppose that we have the following paths where ``main`` is the path of the main
 directory and ``sub`` the one of a sub directory or a file contained in the main
 directory.
 
 python::
     main = "/Users/projects/source_dev"
-    sub  = "/Users/projects/source_dev/Mistool/osPlus.py"
+    sub  = "/Users/projects/source_dev/misTool/os_use.py"
 
 The function will return in that case the following string which always begin
 with one slash ``/``.
 
 python::
-    "/Mistool/osPlus.py"
+    "/misTool/os_use.py"
     """
 # Special case of the same path !
     if main == sub:
-        raise OsUseError(
-            "The main path and the sub-path are equal."
-        )
+        raise OsUseError("The main path and the sub-path are equal.")
 
 # We clean the path in case of they contain things like ``../``.
     main = os.path.normpath(main)
     sub  = os.path.normpath(sub)
 
 # The main path must finish by one backslash because
-#     "python/Mistool/source_dev/Mistool/osPlus.py"
+#     "python/misTool/source_dev/misTool/os_use.py"
 # is not one sub path of
-#     "python/Mistool/source".
+#     "python/misTool/source".
 
     if main[-1] != SEP:
         main += SEP
@@ -162,29 +201,34 @@ def relativeDepth(
     sub
 ):
     """
+-----------------
+Small description
+-----------------
+
 Suppose that we have the following paths where ``main`` is the path of the main
 directory and ``sub`` the one of a sub directory or a file contained in the main
 directory. Here are some examples.
 
-    1) The function will return ``1`` in the following case. This means that the
-    file path::``osPlus.py`` is contained in one simple sub directory of the
-    main directory.
+    1) The function will return ``1`` in the following case.
 
     python::
         main = "/Users/projects/source_dev"
-        sub  = "/Users/projects/source_dev/Mistool/osPlus.py"
+        sub  = "/Users/projects/source_dev/misTool/os_use.py"
+
+    This means that the file path::``os_use.py`` is contained in one simple sub
+    directory of the main directory.
 
     2) In the following case, the function will return ``2``.
 
     python::
         main = "/Users/projects/source_dev"
-        sub  = "/Users/projects/source_dev/Mistool/os/osPlus.py"
+        sub  = "/Users/projects/source_dev/misTool/os/os_use.py"
 
     3) For the last example just after, the value returned will be ``0``.
 
     python::
         main = "/Users/projects/source_dev"
-        sub  = "/Users/projects/source_dev/osPlus.py"
+        sub  = "/Users/projects/source_dev/os_use.py"
     """
     return relativePath(
         main        = main,
@@ -195,8 +239,12 @@ def commonPath(
     listPath
 ):
     """
+-----------------
+Small description
+-----------------
+
 This function returns the smaller directory that contains the objects having the
-paths ``path1`` and ``path2``.
+paths given in the list ``listPath``.
     """
     if len(listPath) < 2:
         raise OsUseError(
@@ -223,33 +271,18 @@ paths ``path1`` and ``path2``.
         ])
 
 
-# ------------- #
-# -- READING -- #
-# ------------- #
-
-def readTextFile(
-    path,
-    encoding = 'utf-8'
-):
-    """
-This function returns the text like content of one file given by its path.
-    """
-    with open(
-        path,
-        mode     = "r",
-        encoding = encoding
-    ) as f:
-        return f.read()
-
-
 # ------------------------------------- #
 # -- OPENING WITH ASSOCIATED PROGRAM -- #
 # ------------------------------------- #
 
 def watch(path):
     """
-This function open one directory, or one file. Indeed, files are opened within
-their associated applications, if this last ones exist.
+-----------------
+Small description
+-----------------
+
+This function tries to open one directory, or one file. Indeed, files are opened
+within their associated applications, if this last ones exist.
     """
 # Nothing to open...
     isOneFile = isFile(path)
@@ -289,14 +322,45 @@ their associated applications, if this last ones exist.
         )
 
 
+# ------------- #
+# -- READING -- #
+# ------------- #
+
+def readTextFile(
+    path,
+    encoding = "utf-8"
+):
+    """
+-----------------
+Small description
+-----------------
+
+This function returns the text like content of one file given by its path.
+
+You can indicate the encoding of the file with the optional argument
+``encoding`` whose dfault value is ``"utf-8"``. The available encodings are the
+same as the ones for the standard ¨python function ``open``.
+    """
+    with open(
+        path,
+        mode     = "r",
+        encoding = encoding
+    ) as f:
+        return f.read()
+
+
 # ----------------------------------- #
 # -- CREATION, DELETION AND MOVING -- #
 # ----------------------------------- #
 
 def makeDir(path):
     """
-This function build the directory with the given path. If one parent directory
-must be build, the function will do the job.
+-----------------
+Small description
+-----------------
+
+This function build the directory with the given path ``path``. If one parent
+directory must be build, the function will do the job.
     """
     if not isDir(path):
         os.makedirs(path)
@@ -307,7 +371,15 @@ def makeTextFile(
     encoding = 'utf-8'
 ):
     """
-This function build the file with the given path and the text like content.
+-----------------
+Small description
+-----------------
+
+This function build the file with the given path ``path`` and the text like content ``text``.
+
+You can indicate the encoding of the file with the optional argument
+``encoding`` whose dfault value is ``"utf-8"``. The available encodings are the
+same as the ones for the standard ¨python function ``open``.
     """
     makeDir(parentDir(path))
 
@@ -323,9 +395,13 @@ def move(
     destination
 ):
     """
-This function moves the file or the directory from ``source`` to
-``destination``. If the source and the destination has the same parent
-directory, then you just rename the file or the directory.
+-----------------
+Small description
+-----------------
+
+This function moves the file or the directory from the path ``source`` to the
+path ``destination``. If the source and the destination have the same parent
+directory, then the final result is just a renaming of the file or directory.
     """
     if isDir(path):
         os.renames(source, destination)
@@ -341,8 +417,12 @@ def copy(
     destination
 ):
     """
-This function copy the file having the path ``source`` to the destination given
-by the path ``destination``.
+-----------------
+Small description
+-----------------
+
+This function copy the file having the path ``source`` to the destination path
+``destination``.
     """
     if isFile(source):
         dir = parentDir(destination)
@@ -364,7 +444,11 @@ by the path ``destination``.
 
 def destroy(path):
     """
-This function removes the directory or the file given by its path.
+-----------------
+Small description
+-----------------
+
+This function removes the directory or the file given by its path ``path``.
     """
     if isDir(path):
         shutil.rmtree(path)
@@ -378,9 +462,18 @@ def clean(
     depth = 0
 ):
     """
-This function removes extra files in one directory regarding to their extension.
+-----------------
+Small description
+-----------------
 
-The variables are the following ones.
+This function removes files in one directory regarding to their extension.
+
+
+-------------
+The arguments
+-------------
+
+This functions uses the following variables.
 
     1) ``path`` is simply the path of the directory to clean.
 
@@ -409,6 +502,10 @@ def __isSubDepthGood(
     depth
 ):
     """
+-----------------
+Small description
+-----------------
+
 This small function is used by ``nextFile`` so as to know if one directory must
 be inspected or not.
     """
@@ -418,28 +515,36 @@ be inspected or not.
     elif depth == 0:
         return bool(main == sub)
 
-# ``relativeDepth``  sends logically one error if the two directories are equal,
+# ``relativeDepth`` sends logically one error if the two directories are equal,
 # so we have to take care of this very special case.
     elif main == sub:
         return True
 
     else:
 # The use of ``... + 1`` in the test comes from the fact we work with files
-# contained in the sub directory, and the depth of this files is equal to the
-# one of sub directory the plus one.
+# contained in the sub directory, and the depth of this file is equal to the
+# one of the sub directory plus one.
         return bool(
-            relativeDepth(main = main, sub = sub) <= depth - 1
+            relativeDepth(main = main, sub = sub) + 1 <= depth
         )
 
 def __toKeepToDiscard(extVar):
+    """
+-----------------
+Small description
+-----------------
+
+This small function is used by ``nextFile`` so as to produce two dictionaries
+``extToKeep`` and ``extToDiscard`` from the variable ``ext``.
+    """
     extToKeep = extVar.get('keep', [])
 
-    if type(extToKeep) == str:
+    if isinstance(extToKeep, str):
         extToKeep = [extToKeep]
 
     extToDiscard = extVar.get('discard', [])
 
-    if type(extToDiscard) == str:
+    if isinstance(extToDiscard, str):
         extToDiscard = [extToDiscard]
 
     return extToKeep, extToDiscard
@@ -452,10 +557,71 @@ def nextFile(
     keepDir = None
 ):
     """
-This function is one iterator that sends infos about files that respects some
-constraints. At each iteration, the function returns the whole path of the file.
+-----------------
+Small description
+-----------------
 
-The variables are the following ones.
+This function is an iterator that sends path of files in a directory withe the
+possibility to use some criteria of research.
+
+
+Suppose for example that we have the following directory structure.
+
+directory::
+    + mistool
+        * __init__.py
+        * description.rst
+        * latex_use.py
+        * os_use.py
+        * ...
+        + change_log
+            + 2012
+                * 07.pdf
+                * 08.pdf
+                * 09.pdf
+        + debug
+            * debug_latex_use.py
+            * debug_os_use.py
+            + debug_latex_use
+                * latexTest.pdf
+                * latexTest.tex
+                * latexTestBuilder.py
+                * ...
+        + toUse
+            + latex
+                * ...
+
+
+Let's consider the following code.
+
+python::
+    from mistool import os_use
+
+    for onePath in os_use.nextFile(
+        main  = "/Users/mistool",
+        ext   = {'keep': "py"},
+        depth = -1
+    ):
+        print(onePath)
+
+
+If we launch the preceding code in a terminal, then we obtain the following
+outputs.
+
+terminal::
+    /Users/mistool/__init__.py
+    /Users/mistool/latex_use.py
+    /Users/mistool/os_use.py
+    /Users/mistool/debug/debug_latex_use.py
+    /Users/mistool/debug/debug_os_use.py
+    /Users/mistool/debug/debug_latex_use/latexTestBuilder.py
+
+
+-------------
+The arguments
+-------------
+
+This function uses the following variables.
 
     1) ``main`` is simply the path of the main directory to analyse.
 
@@ -529,12 +695,12 @@ The variables are the following ones.
             }
         }
 
-    The value of the key ``'inherit'`` can be ``True``, or ``False`` which is
-    the default value, but you can also use couple of boolean values like
-    ``(False, True)`` which asks to only inherit the extensions for the files to
-    discard.
+    The value associated to the key ``'inherit'`` can be a boolean argument, but
+    you can also use couple of boolean values like ``(False, True)`` which asks
+    to only inherit the extensions for the files to discard. By default, the key
+    ``'inherit'`` is associated to ``False``.
 
-    5) The variable ``keepDir`` has been added to be used by the class
+    5) The variable ``keepDir`` has been added so as to be used by the class
     ``TreeDir``, but you can play with it if you want. The possible values are
     the following ones.
 
@@ -665,7 +831,11 @@ The variables are the following ones.
 
 def listFile(*args, **kwargs):
     """
-This function is similar to the function ``nextFile`` and it has the same
+-----------------
+Small description
+-----------------
+
+This function is similar to the function ``nextFile``, and it has the same
 variables that the ones of ``nextFile``, but instead of sending infos about the
 files found one at a time, this function directly sends the whole list of the
 infos found.
@@ -676,38 +846,82 @@ list returned by ``listFile``.
     """
 # The use of ``*args`` and ``**kwargs`` makes it very easy to implement the fact
 # that ``listFile`` and ``nextFile`` have the same variables.
-    theList = []
+    return [p for p in nextFile(*args, **kwargs)]
 
-    for onePath in nextFile(*args, **kwargs):
-        theList.append(onePath)
-
-    return theList
 
 class DirView(object):
     """
+-----------------
+Small description
+-----------------
+
 This class displays the tree structure of one directory with the possibility to
-keep only some relevant informations.
+keep only some relevant informations like in the following example.
 
-Indeed, this class uses the variables ``main``, ``ext``, ``depth`` and ``sub``
-and ``keepDir`` which have exactly the same meaning and behavior that with the
-function ``nextFile``, except that here the default value of ``keepDir`` is
-``"minimal"`` and not ``None``.
+code::
+    + misTool
+        * __init__.py
+        * latexUse.py
+        * os_use.py
+        * ...
+        + change_log
+            + 2012
+                * 07.pdf
+                * 08.pdf
+                * 09.pdf
+        + debug
+            * debug_latexUse.py
+            * debug_os_use.py
+            + debug_latexUse
+                * latexTest.pdf
+                * latexTest.tex
+                * latexTestBuilder.py
+                * ...
+        + toUse
+            + latex
+                * ...
 
-There is also two other variables which control the way the tree structure will
-be displayed.
 
-    1) ``output`` is for the writings of the paths.
+This output has been obtained with the following ¨python code.
 
-        a) The default value ``"all"`` will display the whole paths of the files
-        and directories found.
+python::
+    from mistool import os_use
 
-        b) ``"relative"`` will display relative paths comparing to the main
+    dirView = os_use.dirView(
+        main    = "/Users/misTool",
+        ext     = {'keep': ["py", "txt", "tex", "pdf"]},
+        depth   = -1,
+        keepDir = "All",
+        output  = "short",
+        seeMain = True
+    )
+
+    print(dirView.ascii)
+
+
+-------------
+The arguments
+-------------
+
+This class uses the following variables.
+
+    1) The variables ``main``, ``ext``, ``depth`` and ``sub`` and ``keepDir``
+    have exactly the same meaning and behavior that they have with the function
+    ``nextFile``, except that here the default value of ``keepDir`` is
+    ``"minimal"`` and not ``None``.
+
+    2) ``output`` is for the writings of the paths.
+
+        a) The default value ``"all"`` asks to display the whole paths of the
+        files and directories found.
+
+        b) ``"relative"`` asks to display relative paths comparing to the main
         directory analysed.
 
-        c) ``"short"`` will only display names of directories found, and names,
-        with its extensions, of the files found.
+        c) ``"short"`` asks to only display names of directories found, and
+        names, with its extensions, of the files found.
 
-    2) ``seeMain`` is one boolean value to display or not the main directory
+    3) ``seeMain`` is one boolean value to display or not the main directory
     which is analyzed. The default value is ``True``.
     """
     ASCII_DECORATION = {
@@ -744,7 +958,11 @@ be displayed.
 
     def build(self):
         """
-This function builds one list of dictionary of the following kind.
+-----------------
+Small description
+-----------------
+
+This method builds one list of dictionaries of the following kind.
 
 python::
     {
@@ -812,6 +1030,13 @@ python::
                 })
 
     def __otherFiles(self, onePath):
+        """
+-----------------
+Small description
+-----------------
+
+This method displays text indicated that other files are in the directory.
+        """
         return onePath.endswith("...")
 
     def pathToDisplay(
@@ -840,6 +1065,10 @@ python::
     @property
     def ascii(self):
         """
+-----------------
+Small description
+-----------------
+
 This method returns a simple ASCCI tree view of the tree structure.
         """
         if 'ascii' not in self.format:
@@ -875,6 +1104,10 @@ This method returns a simple ASCCI tree view of the tree structure.
 
 def pathEnv():
     """
+-----------------
+Small description
+-----------------
+
 This function simply returns the variable ``PATH`` that contains paths of some
 executables known by your OS.
     """
@@ -882,6 +1115,10 @@ executables known by your OS.
 
 def system():
     """
+-----------------
+Small description
+-----------------
+
 The purpose of this function is to give the name, in lower case, of the OS used.
 Possible names can be "windows", "mac", "linux" and also "java".
     """
